@@ -94,46 +94,46 @@ List GASFilter_multi(arma::mat mY, arma::vec vKappa, arma::mat mA, arma::mat mB,
   return out;
 }
 
-List FFBS(arma::mat allprobs, arma::vec delta, arma::mat mGamma, int iJ, int iT){
-
-  arma::mat lalpha=zeros(iJ,iT);
-  arma::mat lbeta=zeros(iJ,iT);
-
-  arma::vec foo(iJ);
-  double sumfoo,lscale;
-  int i;
-
-  foo    = delta % allprobs.row(0).t();
-  sumfoo = sum(foo);
-  lscale = log(sumfoo);
-  foo    = foo/sumfoo ;
-
-  lalpha.col(0) = log(foo)+lscale;
-  for(i=1;i<iT;i++){
-    foo           = (foo.t() * mGamma).t() % allprobs.row(i).t();
-    sumfoo        = sum(foo);
-    lscale        = lscale+log(sumfoo);
-    foo           = foo/sumfoo;
-    lalpha.col(i) = log(foo)+lscale;
-  }
-  for(i=0;i<iJ;i++) {
-    foo(i)=1.0/iJ;
-  }
-  lscale = log(double(iJ));
-  for(i = iT-2; i >= 0; i--){
-    foo          = mGamma * (allprobs.row(i+1).t() % foo);
-    lbeta.col(i) = log(foo)+lscale;
-    sumfoo       = sum(foo);
-    foo          = foo/sumfoo;
-    lscale       = lscale+log(sumfoo);
-  }
-
-  List FS;
-  FS["lalpha"]=lalpha;
-  FS["lbeta"]=lbeta;
-
-  return FS;
-}
+// List FFBS(arma::mat allprobs, arma::vec delta, arma::mat mGamma, int iJ, int iT){
+//
+//   arma::mat lalpha=zeros(iJ,iT);
+//   arma::mat lbeta=zeros(iJ,iT);
+//
+//   arma::vec foo(iJ);
+//   double sumfoo,lscale;
+//   int i;
+//
+//   foo    = delta % allprobs.row(0).t();
+//   sumfoo = sum(foo);
+//   lscale = log(sumfoo);
+//   foo    = foo/sumfoo ;
+//
+//   lalpha.col(0) = log(foo)+lscale;
+//   for(i=1;i<iT;i++){
+//     foo           = (foo.t() * mGamma).t() % allprobs.row(i).t();
+//     sumfoo        = sum(foo);
+//     lscale        = lscale+log(sumfoo);
+//     foo           = foo/sumfoo;
+//     lalpha.col(i) = log(foo)+lscale;
+//   }
+//   for(i=0;i<iJ;i++) {
+//     foo(i)=1.0/iJ;
+//   }
+//   lscale = log(double(iJ));
+//   for(i = iT-2; i >= 0; i--){
+//     foo          = mGamma * (allprobs.row(i+1).t() % foo);
+//     lbeta.col(i) = log(foo)+lscale;
+//     sumfoo       = sum(foo);
+//     foo          = foo/sumfoo;
+//     lscale       = lscale+log(sumfoo);
+//   }
+//
+//   List FS;
+//   FS["lalpha"]=lalpha;
+//   FS["lbeta"]=lbeta;
+//
+//   return FS;
+// }
 
 // List HMMlalphabeta(arma::vec vY, arma::mat mGamma, arma::vec vMu, arma::vec vSigma2, int T, int K){
 //
